summary refs log tree commit diff
path: root/gnu/installer.scm
diff options
context:
space:
mode:
authorMathieu Othacehe <m.othacehe@gmail.com>2018-12-05 14:36:22 +0900
committerLudovic Courtès <ludo@gnu.org>2019-01-17 14:04:23 +0100
commitc088b2e47f6675199f1ef545df7d04d4532e64e3 (patch)
tree335f80e187ea1da73fbb39a1ca296166e714db90 /gnu/installer.scm
parentdc5f3275ecbddc804875899e9e457299a835d7ab (diff)
downloadguix-c088b2e47f6675199f1ef545df7d04d4532e64e3.tar.gz
installer: Do not ask for keyboard model.
Suppose that the keyboard model is "pc105".

* gnu/installer.scm (apply-keymap): Remove model ...
* gnu/installer/newt/keymap.scm (run-keymap-page): passed here.
(run-model-page): remove procedure
* gnu/installer/record.scm (installer): Edit keymap-page prototype in comment.
* gnu/installer/keymap.scm (default-keyboard-model): New exported parameter.
Diffstat (limited to 'gnu/installer.scm')
-rw-r--r--gnu/installer.scm10
1 files changed, 5 insertions, 5 deletions
diff --git a/gnu/installer.scm b/gnu/installer.scm
index e53acb12f4..4a587eb35b 100644
--- a/gnu/installer.scm
+++ b/gnu/installer.scm
@@ -133,10 +133,11 @@ been performed at build time."
           result))))
 
 (define apply-keymap
   ;; Apply the specified keymap.
   #~(match-lambda
-      ((model layout variant)
-       (kmscon-update-keymap model layout variant))))
+      ((layout variant)
+       (kmscon-update-keymap (default-keyboard-model)
+                             layout variant))))
 
 (define* (compute-keymap-step)
   "Return a gexp that runs the keymap-page of INSTALLER and install the
@@ -150,8 +151,7 @@ selected keymap."
                                    "/share/X11/xkb/rules/base.xml")))
                (lambda (models layouts)
                  ((installer-keymap-page current-installer)
-                  #:models models
-                  #:layouts layouts)))))
+                  layouts)))))
         (#$apply-keymap result))))
 
 (define (installer-steps)
@@ -133,10 +133,11 @@ been performed at build time."
 
 (define apply-keymap
-  ;; Apply the specified keymap.
+  ;; Apply the specified keymap. Use the default keyboard model.
   #~(match-lambda